from psycopg2.extras import NumericRange

from meleager.models import Author

from ..helpers import to_date
from .description import get_or_create_description
from .name import get_or_create_name


def create_authors(author_data, language_id_to_model, user_data, cities_data):
    author_id_to_model = {}

    for author in author_data:
        values = {
            "city_born": None,
            "city_died": None,
            "born": None,
            "born_range": 0,
            "died": None,
            "died_range": 0,
            "creator": user_data[author["id_user"]["id_user"]],
            "last_editor": user_data[author["id_user"]["id_user"]],
            "created_at": to_date(author["createdAt"]),
            "updated_at": to_date(author["updatedAt"]),
        }

        if "city_born" in author:
            values["city_born"] = cities_data[author["city_born"]["id_city"]]

        if "city_died" in author:
            values["city_died"] = cities_data[author["city_died"]["id_city"]]

        if "born" in author:
            values["born"] = author["born"]

        if "born_range" in author and author["born_range"] is not None:
            if values["born"] is not None:
                values["born_range_year_date"] = NumericRange(
                    int(values["born"] - author["born_range"] / 2),
                    int(values["born"] + values["born_range"] / 2),
                )
            else:
                values["born_range_year_date"] = None

        if "died" in author:
            values["died"] = author["died"]

        if "died_range" in author and author["died_range"] is not None:
            if values["died"] is not None:
                values["died_range_year_date"] = NumericRange(
                    int(values["died"] - author["died_range"] / 2),
                    int(values["died"] + author["died_range"] / 2),
                )
            else:
                values["died_range_year_date"] = None

        for useless_value in ("born", "born_range", "died", "died_range"):
            del values[useless_value]

        if author["id_author"] in author_id_to_model:
            author_obj = author_id_to_model[author["id_author"]]
            Author.objects.filter(pk=author_obj.pk).update(**values)
        else:
            author_obj = Author.objects.create(**values)

        for dname in author["versions"]:
            name_obj = get_or_create_name(
                name=dname["name"],
                language=language_id_to_model[dname["id_language"]],
                creator=user_data[dname["id_user"]],
                last_editor=user_data[dname["id_user"]],
                created_at=to_date(dname["createdAt"]),
                updated_at=to_date(dname["updatedAt"]),
            )

            author_obj.names.add(name_obj)

        author_id_to_model[author["id_author"]] = author_obj

    return author_id_to_model
