from django.contrib.gis.geos import Point
from meleager.models import City, Description

from ..helpers import to_date
from .description import get_or_create_description
from .name import get_or_create_name


def create_cities(cities_data, user_data, language_id_to_model):
    city_id_to_model = dict()

    for city in cities_data:
        if city["GPS"] is not None:
            GPS_x, GPS_y = city["GPS"].split(",")
            location = Point(float(GPS_x), float(GPS_y))
        else:
            location = None

        kwargs = {
            "location": location,
            "creator": user_data[city["id_user"]["id_user"]],
            "last_editor": user_data[city["id_user"]["id_user"]],
            "created_at": city["createdAt"],
            "updated_at": city["updatedAt"],
        }

        if city["id_city"] in city_id_to_model:
            city_obj = city_id_to_model[city["id_city"]]
            City.objects.filter(pk=city_obj.pk).update(**kwargs)
        else:
            city_obj = City.objects.create(**kwargs)

        for version in city["versions"]:
            name_obj = get_or_create_name(
                name=version["name"],
                language=language_id_to_model[version["id_language"]],
                creator=user_data[version["id_user"]],
                last_editor=user_data[version["id_user"]],
                created_at=to_date(version["createdAt"]),
                updated_at=to_date(version["updatedAt"]),
            )

            city_obj.names.add(name_obj)

        city_id_to_model[city["id_city"]] = city_obj

    return city_id_to_model
