from meleager.models import Manuscript, Medium
from ..helpers import to_date
from .description import get_or_create_description


def create_manuscript(image, user_data):
    manuscript_obj, created = Manuscript.objects.update_or_create(
        url_image=image["URL"],
        defaults={
            "creator": user_data[image["id_user"]["id_user"]],
            "last_editor": user_data[image["id_user"]["id_user"]],
            "created_at": to_date(image["createdAt"]),
            "updated_at": to_date(image["updatedAt"]),
        },
    )

    return manuscript_obj


def create_image(image, user_data):
    img_obj, created = Medium.objects.update_or_create(
        url_image=image["URL"],
        defaults={
            "creator": user_data[image["id_user"]["id_user"]],
            "last_editor": user_data[image["id_user"]["id_user"]],
            "created_at": to_date(image["createdAt"]),
            "updated_at": to_date(image["updatedAt"]),
        },
    )

    return img_obj


def create_images(
    images_data, user_data, passage_data, scholium_data, language_mapping
):

    for image in images_data:
        # {
        # "authors":[],
        # "cities":[],
        # "eras":[],
        # "keywords":[],
        # "scholies":[],
        # "entities":[],
        # "manuscripts":[],
        # "notes":[],
        # "id_user":{"id_user":1,"displayName":"ImportScript","roles":null,"admin":true,"first_name":"","last_name":"","institution":"API","country":"","defaultEdition":"UdeM","createdAt":"2017-05-26T18:33:43.000Z","updatedAt":"2017-09-15T15:00:27.000Z"},
        # "id_image":2,
        # "date":null,
        # "date_range":null,
        # "URL":"https://www.w3schools.com/css/trolltunga.jpg",
        # "file":null,
        # "title":"fjord",
        # "credit":"to be deleted",
        # "createdAt":"2017-09-15T20:04:14.000Z",
        # "updatedAt":"2017-09-15T20:04:14.000Z"
        # }

        objects = list()

        if image["manuscripts"]:
            manuscript_obj = create_manuscript(image, user_data)
            objects.append(manuscript_obj)
            for entity in image["manuscripts"]:
                passage_data[entity["id_entity"]].manuscripts.add(manuscript_obj)

        if image["scholies"]:
            manuscript_obj = create_manuscript(image, user_data)
            objects.append(manuscript_obj)
            for scholie in image["scholies"]:
                scholium_data[scholie["id_scholie"]].manuscripts.add(manuscript_obj)

        if image["entities"]:
            image_obj = create_image(image, user_data)
            objects.append(image_obj)
            for entity in image["entities"]:
                passage_data[entity["id_entity"]].images.add(image_obj)

        # TOOD : ADD NOTES / COMMENTS
        # https://framagit.org/anthologie-palatine/anthologyontology/-/issues/47

        title_desc = get_or_create_description(
            image["title"],
            language_mapping["français moderne"],
            user_data[image["id_user"]["id_user"]],
            user_data[image["id_user"]["id_user"]],
            created_at=to_date(image["createdAt"]),
            updated_at=to_date(image["updatedAt"]),
        )

        credit_desc = get_or_create_description(
            image["credit"],
            language_mapping["français moderne"],
            user_data[image["id_user"]["id_user"]],
            user_data[image["id_user"]["id_user"]],
            created_at=to_date(image["createdAt"]),
            updated_at=to_date(image["updatedAt"]),
        )

        for obj in objects:
            obj.descriptions.add(title_desc)
            obj.descriptions.add(credit_desc)
