from meleager.models import Keyword, KeywordCategory

from ..helpers import to_date
from .description import get_or_create_description
from .name import get_or_create_name


def create_keyword_categories(cat_data, user_data, default_user_id=1):
    keyword_category_id_to_model = {}

    for category in cat_data:
        user_id = category.get("id_user")
        if not user_id:
            user_id = default_user_id

        name_obj = get_or_create_name(
            name=category["title"],
            language="FRA",
            creator=user_data[user_id],
            last_editor=user_data[user_id],
            created_at=category["createdAt"],
            updated_at=category["updatedAt"],
        )

        kw_cat_pk = None
        if category["id_keyword_category"] in keyword_category_id_to_model:
            kw_cat_pk = category["id_keyword_category"]
        kw_cat, created = KeywordCategory.objects.update_or_create(
            pk=kw_cat_pk,
            defaults={"creator": user_data[user_id], "last_editor": user_data[user_id]},
        )

        kw_cat.names.add(name_obj)
        keyword_category_id_to_model[category["id_keyword_category"]] = kw_cat

    return keyword_category_id_to_model


def create_keywords(kw_data, cat_data, user_data, language_id_to_model):

    keyword_id_to_model = {}

    for keyword in kw_data:
        if "category" not in keyword:
            print(
                "No category for keyword",
                '"' + keyword["versions"][0]["title"] + '"',
                "skipping",
            )
            continue

        kw_pk = None
        if keyword["id_keyword"] in keyword_id_to_model:
            kw_pk = keyword_id_to_model[keyword["id_keyword"]].pk

        kw_obj, created = Keyword.objects.update_or_create(
            pk=kw_pk,
            defaults={
                "category": cat_data[keyword["category"]["id_keyword_category"]],
                "creator": user_data[keyword["id_user"]["id_user"]],
                "last_editor": user_data[keyword["id_user"]["id_user"]],
            },
        )

        for version in keyword["versions"]:
            name_obj = get_or_create_name(
                name=version["title"],
                language=language_id_to_model[version["id_language"]],
                creator=user_data[version["id_user"]],
                last_editor=user_data[version["id_user"]],
                created_at=to_date(version["createdAt"]),
                updated_at=to_date(version["updatedAt"]),
            )
            kw_obj.names.add(name_obj)

        keyword_id_to_model[keyword["id_keyword"]] = kw_obj

    return keyword_id_to_model
