from meleager.models import Comment

from ..helpers import to_date
from .description import get_or_create_description


def create_notes(notes_data, language_id_to_model, user_data, passage_data):

    comment_id_to_model = dict()

    for note in notes_data:
        # {
        #  "versions":[{"id_note_version":3,"id_note":4,"id_user":2,"id_group":null,"id_language":2,"text":"2 dans le Codex Palatinus 23, p. 88\n\nCette épigramme se trouve à la page 88 du manuscrit palatin, au début de la partie dédiée aux épigrammes d’amour","createdAt":"2017-09-15T11:14:42.000Z","updatedAt":"2017-09-15T11:14:42.000Z"}],
        #  "entities":[{"id_entity":8,"title":"Greek Anthology 5.2","date":null,"date_range":null,"createdAt":"2017-05-29T09:52:49.000Z","updatedAt":"2020-07-27T23:26:13.000Z","id_book":null,"id_era":null,"id_genre":null,"id_user":1,"id_group":null}],"images":[],"id_user":{"id_user":2,"displayName":"marviro","roles":null,"admin":true,"first_name":"Marcello","last_name":"Vitali-Rosati","institution":"Université de Montréal","country":"Canada","defaultEdition":"Marcello","createdAt":"2017-05-27T11:12:12.000Z","updatedAt":"2020-04-18T11:01:32.000Z"},
        #  "id_note":4,
        #  "title":"Position dans le manuscrit",
        #  "createdAt":"2017-09-15T11:14:30.000Z",
        #  "updatedAt":"2017-09-15T11:14:50.000Z"
        # }

        texts = []
        for version in note["versions"]:
            description = get_or_create_description(
                description=version["text"],
                language=language_id_to_model[version["id_language"]],
                creator=user_data[version["id_user"]],
                last_editor=user_data[version["id_user"]],
                created_at=to_date(version["createdAt"]),
                updated_at=to_date(version["updatedAt"]),
            )
            texts.append(description)

        comment_obj, created = Comment.objects.get_or_create(
            comment_type="user_note",
            comment_title=note["title"],
            last_editor=user_data[note["id_user"]["id_user"]],
            creator=user_data[note["id_user"]["id_user"]],
            created_at=to_date(note["createdAt"]),
            updated_at=to_date(note["updatedAt"]),
        )

        comment_obj.descriptions.add(*texts)
        comment_id_to_model[note["id_note"]] = comment_obj

        for entity in note["entities"]:
            passage_data[entity["id_entity"]].comments.add(
                comment_id_to_model[note["id_note"]]
            )

    return comment_id_to_model
