import logging
from meleager.models import Scholium, Text

from ..helpers import to_date, to_id
from .description import get_or_create_description

logger = logging.getLogger(__name__)


def create_scholies(scholies_data, user_data, passage_data, language_id_to_model):

    scholium_id_to_model = {}

    for scholium in scholies_data:
        # {"versions":[
        #   {"id_scholie_version":1,"id_scholie":2,"id_user":2,"id_group":null,"id_language":4,"text":"ἐις Σθενελαΐδα τὴν ἐταίραν","edition":null,"createdAt":"2017-09-15T11:10:58.000Z","updatedAt":"2017-09-22T14:15:46.000Z"},
        #   {"id_scholie_version":4,"id_scholie":2,"id_user":2,"id_group":null,"id_language":2,"text":"À Sténélaïde, une jeune fille  À Sténélaïde, une jeune fille  À Sténélaïde, une jeune fille ","edition":null,"createdAt":"2017-09-15T11:12:27.000Z","updatedAt":"2017-09-28T14:41:13.000Z"},
        #   {"id_scholie_version":40,"id_scholie":2,"id_user":5,"id_group":null,"id_language":1,"text":"(Dedicato) a Stenelaide\nl’etera","edition":null,"createdAt":"2018-12-18T18:37:08.000Z","updatedAt":"2018-12-18T18:37:08.000Z"}],
        # "entities":[{"id_entity":8,"title":"Greek Anthology 5.2","date":null,"date_range":null,"createdAt":"2017-05-29T09:52:49.000Z","updatedAt":"2020-07-27T23:26:13.000Z","id_book":null,"id_era":null,"id_genre":null,"id_user":1,"id_group":null}],
        # "images":[],
        # "id_user":{"id_user":2,"displayName":"marviro","roles":null,"admin":true,"first_name":"Marcello","last_name":"Vitali-Rosati","institution":"Université de Montréal","country":"Canada","defaultEdition":"Marcello","createdAt":"2017-05-27T11:12:12.000Z","updatedAt":"2020-04-18T11:01:32.000Z"},
        # "id_scholie":2,
        # "title":"5.2.1",
        # "createdAt":"2017-09-15T11:07:20.000Z",
        # "updatedAt":"2020-06-17T07:43:44.000Z"}

        related_passage = scholium["entities"]
        related_passage_obj = None
        try:
            related_passage_id = related_passage.pop()["id_entity"]
            related_passage_obj = passage_data[related_passage_id]
        except IndexError:
            print("!!!! NO PASSAGE FOUND", "Scholium", scholium["id_scholie"])

        try:
            book_number, fragment_identifier, scholium_number = scholium["title"].split(
                "."
            )
        except ValueError:
            print("!!!! Unable to parse scholium title:", scholium["title"])
            continue

        scholium_obj, created = Scholium.objects.update_or_create(
            number=scholium["title"].rsplit(".", 1)[-1],
            passage=related_passage_obj,
            defaults={
                "creator": user_data[scholium["id_user"]["id_user"]],
                "last_editor": user_data[scholium["id_user"]["id_user"]],
                "created_at": to_date(scholium["createdAt"]),
                "updated_at": to_date(scholium["updatedAt"]),
            },
        )
        scholium_id_to_model[scholium["id_scholie"]] = scholium_obj
        action = ["UPDATED", "NEW"][created]

        logger.debug("%s | Scholium %d", action, scholium_obj.pk)

        for version in scholium["versions"]:
            language = language_id_to_model[version["id_language"]]

            text_obj, created = Text.objects.update_or_create(
                scholium=scholium_obj,
                text=version["text"],
                language=language,
                defaults={
                    "status": Text.Status.PUBLISHED,
                    "creator": user_data[version["id_user"]],
                    "last_editor": user_data[version["id_user"]],
                    "created_at": to_date(version["createdAt"]),
                    "updated_at": to_date(version["updatedAt"]),
                },
            )
            action = ["UPDATED", "NEW"][created]
            logger.debug(
                "%s | Text %d (Scholium %d)", action, text_obj.pk, scholium_obj.pk
            )

        # for entity in scholium["entities"]:
        #     passage_data[entity["id_entity"]].scholia.add(scholium_obj)

    return scholium_id_to_model
