import logging

from django.contrib.auth import get_user_model
from django.contrib.auth.models import Group

User = get_user_model()

logger = logging.getLogger(__name__)


def create_users(user_data):
    admin_group, created = Group.objects.get_or_create(name="administrators")

    user_id_to_model = dict()

    for user in user_data:
        wanted_username = user["displayName"]
        try:
            user_obj = User.objects.get(username=wanted_username)
            action = "updated"
        except User.DoesNotExist:
            user_obj = User.objects.create_user(
                username=wanted_username,
            )
            action = "created"

        user_obj.institution = user["institution"]
        user_obj.save()

        if "admin" in user:
            user_obj.groups.add(admin_group)

        user_id_to_model.update({user["id_user"]: user_obj})
        logger.debug(
            "%s user %s (API ID %d), PK %d",
            action.capitalize(),
            user_obj.username,
            user["id_user"],
            user_obj.pk,
        )

    return user_id_to_model
