from json import load

from .constants import LANGUAGES_MAPPING, LANGUAGES_MAPPING_TO_EDITION
from .create import (
    create_authors,
    create_cities,
    create_entities,
    create_images,
    create_keyword_categories,
    create_keywords,
    create_notes,
    create_scholies,
    create_users,
)
from .helpers import OBJECTS_DICT, DataProvider


def do_import(load_from_files=False, save_local_files=False):
    kwargs = {"load_from_file": load_from_files, "save_local_file": save_local_files}
    languages = DataProvider("languages", **kwargs)

    language_id_to_name = {
        l["id_language"]: f"{l['family']} {l['name']}" for l in languages
    }

    language_id_to_model = {
        l["id_language"]: LANGUAGES_MAPPING[language_id_to_name[l["id_language"]]]
        for l in languages
    }

    user_data = DataProvider("users", **kwargs)
    user_id_to_model = create_users(user_data)

    cities_data = DataProvider("cities", **kwargs)
    city_id_to_model = create_cities(
        cities_data, user_id_to_model, language_id_to_model
    )

    author_data = DataProvider("authors", **kwargs)
    author_id_to_model = create_authors(
        author_data, language_id_to_model, user_id_to_model, city_id_to_model
    )

    keyword_category_data = DataProvider("keyword_categories", **kwargs)
    keyword_category_id_to_model = create_keyword_categories(
        keyword_category_data, user_id_to_model
    )

    keyword_data = DataProvider("keywords", **kwargs)
    keyword_id_to_model = create_keywords(
        keyword_data,
        keyword_category_id_to_model,
        user_id_to_model,
        language_id_to_model,
    )

    entity_data = DataProvider("entities", **kwargs)
    passage_id_to_model = create_entities(
        entity_data,
        user_id_to_model,
        author_id_to_model,
        language_id_to_model,
        keyword_id_to_model,
        LANGUAGES_MAPPING_TO_EDITION,
        language_id_to_name,
        LANGUAGES_MAPPING,
    )

    notes_data = DataProvider("notes", **kwargs)
    comment_id_to_model = create_notes(
        notes_data, language_id_to_model, user_id_to_model, passage_id_to_model
    )

    scholies_data = DataProvider("scholies", **kwargs)
    scholies_id_to_model = create_scholies(
        scholies_data, user_id_to_model, passage_id_to_model, language_id_to_model
    )

    images_data = DataProvider("images", **kwargs)
    create_images(
        images_data,
        user_id_to_model,
        passage_id_to_model,
        scholies_id_to_model,
        LANGUAGES_MAPPING,
    )
