from django.contrib.postgres.fields import IntegerRangeField
from django.db import models

from .mixins.descriptable_mixin import DescriptableResourceMixin
from .mixins.editable_mixin import EditableResourceMixin
from .mixins.urn_mixin import AlternativeURNResourceMixin


class Author(
    EditableResourceMixin,
    DescriptableResourceMixin,
    AlternativeURNResourceMixin,
    models.Model,
):
    names = models.ManyToManyField(
        "meleager.Name",
        related_name="mlgr_authors",
        help_text="The multilingual names for this object.",
    )

    city_born = models.ForeignKey(
        "meleager.City",
        on_delete=models.PROTECT,
        null=True,
        blank=True,
        related_name="mlgr_authors_born",
        related_query_name="%(app_label)s_%(class)ss_city_born",
        help_text="The city where this author was born.",
    )

    born_range_year_date = IntegerRangeField(
        null=True, blank=True, help_text="The date range for the author born date."
    )

    city_died = models.ForeignKey(
        "meleager.City",
        on_delete=models.PROTECT,
        null=True,
        blank=True,
        related_name="mlgr_authors_died",
        help_text="The city where this author died.",
    )

    images = models.ManyToManyField(
        "meleager.Medium",
        related_name="mlgr_authors",
        help_text="The images associated to this resource.",
    )

    died_range_year_date = IntegerRangeField(
        null=True, blank=True, help_text="The date range for the author dead date."
    )

    def __str__(self):
        if self.names.first():
            return f"Author {self.names.first().name} ({self.pk})"
        else:
            return f"Author PK {self.pk}"
