from django.db import models

from .mixins import DescriptableResourceMixin, EditableResourceMixin


class KeywordCategory(EditableResourceMixin, DescriptableResourceMixin, models.Model):
    names = models.ManyToManyField(
        "meleager.Name",
        related_name="mlgr_keyword_categories",
        help_text="The multilingual names for this object.",
    )

    def __str__(self):
        if self.names.first():
            return f"Category {self.names.first().name} ({self.pk})"
        else:
            return f"Category PK {self.pk}"

    class Meta:
        verbose_name_plural = "Keyword categories"


class Keyword(EditableResourceMixin, DescriptableResourceMixin, models.Model):
    names = models.ManyToManyField(
        "meleager.Name",
        related_name="mlgr_keywords",
        help_text="The multilingual names for this object.",
    )

    category = models.ForeignKey(
        KeywordCategory,
        on_delete=models.SET_NULL,
        help_text="The category this keyword belongs to.",
        null=True,
    )

    def __str__(self):
        if self.names.first():
            return f"Keyword {self.names.first().name} ({self.pk})"
        else:
            return f"Category PK {self.pk}"
