from django.db import models

from .mixins.descriptable_mixin import DescriptableResourceMixin
from .mixins.editable_mixin import EditableResourceMixin


class MediaTypes(models.TextChoices):
    IMAGE = ("image", "Image")
    VIDEO = ("video", "Video")
    AUDIO = ("audio", "Audio")


class Medium(EditableResourceMixin, DescriptableResourceMixin, models.Model):
    keywords = models.ManyToManyField(
        "meleager.Keyword",
        related_name="mlgr_media",
        help_text="The keywords that tag this resource.",
    )
    type = models.CharField(
        choices=MediaTypes.choices, default=MediaTypes.IMAGE, max_length=8
    )
    url_image = models.URLField(help_text="The URL of this image", max_length=500)

    def __str__(self):
        return f"Medium {self.url_image}"


class Manuscript(EditableResourceMixin, DescriptableResourceMixin, models.Model):
    keywords = models.ManyToManyField(
        "meleager.Keyword",
        related_name="mlgr_manuscripts",
        help_text="The keywords that tag this resource.",
    )
    url_image = models.URLField(help_text="The URL of this image", max_length=500)

    def __str__(self):
        return f"Manuscript {self.url_image}"
