from django.db import models

from .mixins import (
    AlternativeURNResourceMixin,
    DescriptableResourceMixin,
    EditableResourceMixin,
    ValidableResourceMixin,
)


class Scholium(
    EditableResourceMixin,
    ValidableResourceMixin,
    DescriptableResourceMixin,
    AlternativeURNResourceMixin,
    models.Model,
):
    number = models.IntegerField("Scholium ID", db_index=True, null=True)

    passage = models.ForeignKey(
        "meleager.Passage",
        related_name="mlgr_scholia",
        on_delete=models.CASCADE,
        null=True,
    )
    city = models.ForeignKey(
        "meleager.City",
        related_name="mlgr_scholia",
        on_delete=models.SET_NULL,
        null=True,
    )

    manuscripts = models.ManyToManyField(
        "meleager.Manuscript", help_text="The image of the manuscript for this passage."
    )

    images = models.ManyToManyField(
        "meleager.Medium",
        related_name="mlgr_scholia",
        help_text="The images associated to this resource.",
    )

    comments = models.ManyToManyField(
        "meleager.Comment",
        related_name="mlgr_scholia",
        help_text="The comments of this resource.",
    )

    keywords = models.ManyToManyField(
        "meleager.Keyword",
        related_name="mlgr_scholia",
        help_text="The keywords that tag this resource.",
    )

    class Meta:
        verbose_name_plural = "Scholia"
