from django.db import models
from django.template.defaultfilters import truncatewords

from .helpers import Language
from .mixins import EditableResourceMixin, ValidableResourceMixin


class Text(EditableResourceMixin, ValidableResourceMixin, models.Model):
    class Status(models.IntegerChoices):
        DRAFT = 0
        PUBLISHED = 1
        DELETED = 2

    language = models.TextField(choices=Language)

    edition = models.ForeignKey(
        "meleager.Edition",
        on_delete=models.CASCADE,
        null=True,
        blank=True,
        help_text="The edition of this text.",
    )

    status = models.IntegerField(choices=Status.choices, default=Status.PUBLISHED)
    text = models.TextField(help_text="The string of this text")

    passage = models.ForeignKey(
        "meleager.Passage",
        help_text="Passage for this text",
        null=True,
        on_delete=models.CASCADE,
        related_name="texts",
    )
    scholium = models.ForeignKey(
        "meleager.Scholium",
        help_text="Scholium for this text",
        null=True,
        on_delete=models.CASCADE,
        related_name="texts",
    )

    comments = models.ManyToManyField(
        "meleager.Comment",
        related_name="texts",
        help_text="The comments of this resource.",
    )

    def __str__(self):
        return f"Text ({truncatewords(self.text, 5)})"
