from django.urls import path, re_path

from .views import index_view

from .views.passage import PassageDetail, PassageUpdate
from .views.scholium import scholium_view
from .views.authors import AuthorCreate, AuthorDetail, AuthorList, AuthorUpdate
from .views.cities import CityCreate, CityDetail, CityList, CityUpdate
from .views.comments import add_comment_from_passage

app_name = "web"

urlpatterns = [
    path("", index_view, name="index"),
    re_path(
        "passages/urn:cts:greekLit:tlg7000.tlg001.ag:(?P<book>\d+).(?P<fragment>\d+)(?P<sub_fragment>[^/]*)",
        PassageDetail.as_view(),
        name="passage-detail",
    ),
    path(
        "passages/urn:cts:greekLit:tlg5011.tlg001.sag:<int:book>.<int:fragment>.<int:number>",
        scholium_view,
        name="scholium",
    ),
    path("passages/<int:pk>/edit", PassageUpdate.as_view(), name="passage-update"),
    path("authors", AuthorList.as_view(), name="author-list"),
    path("authors/new", AuthorCreate.as_view(), name="author-update"),
    path("authors/<int:pk>", AuthorDetail.as_view(), name="author-detail"),
    path("authors/<int:pk>/edit", AuthorUpdate.as_view(), name="author-update"),
    path("cities", CityList.as_view(), name="city-list"),
    path("cities/new", CityCreate.as_view(), name="city-update"),
    path("cities/<int:pk>", CityDetail.as_view(), name="city-detail"),
    path("cities/<int:pk>/edit", CityUpdate.as_view(), name="city-update"),
    path(
        "comments/add/passage/<int:passage_pk>",
        add_comment_from_passage,
        name="comment-add",
    ),
]
