from django.shortcuts import get_object_or_404, render
from django.views import generic
from django import forms
from web.models import APPassage
from web.forms.passage import PassageForm
from web.forms.comment_description import CommentDescriptionForm


class PassageDetail(generic.DetailView):
    model = APPassage
    template_name = "web/passage.html"
    context_object_name = "passage"

    def get_object(self):
        obj = get_object_or_404(
            APPassage,
            book__number=self.kwargs.get("book"),
            fragment=self.kwargs.get("fragment"),
            sub_fragment=self.kwargs.get("sub_fragment", ""),
        )
        return obj

    def get_context_data(self, **kwargs):
        context = super().get_context_data(**kwargs)
        context["comment_form"] = CommentDescriptionForm()
        # Exclude texts without a text, otherwise forloop counters
        # in templates would be inconsistent.
        # TODISCUSS: maybe an import_ap issue?
        context["texts"] = self.get_object().texts.exclude(text="")
        return context


class PassageUpdate(generic.UpdateView):
    model = APPassage
    template_name = "web/passage_form.html"
    form_class = PassageForm
